@@ -43,6 +43,7 @@ import ConfigParser #safe application configuration
 from obd2_codes import pcodes
 from obd2_codes import ptest
 
+
 #import sys
 import dbus
 from bluetooth import *
@@ -128,14 +129,8 @@ class MyApp(wx.App):
             wx.ListCtrl.__init__(self,parent,id,pos,size,style)
             ListCtrlAutoWidthMixin.__init__(self)
 
-            bus = dbus.SystemBus()
-            manager = dbus.Interface(bus.get_object("org.bluez", "/"),"org.bluez.Manager")
-            adapter = dbus.Interface(bus.get_object("org.bluez", manager.DefaultAdapter()),"org.bluez.Adapter")
-            adapter.SetProperty('Powered',True)
 
-
-
-                
+               
     class sensorProducer(threading.Thread):
         def __init__(self, _notify_window,portName,SERTIMEOUT,RECONNATTEMPTS,_nb):
 
@@ -193,6 +188,8 @@ class MyApp(wx.App):
 
               
             wx.PostEvent(self._notify_window, StatusEvent([0,1,"Connected"]))
+            os.popen('dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:"Connected to ECU"')
+
             wx.PostEvent(self._notify_window, StatusEvent([2,1,self.port.ELMver]))
             prevstate=-1
             curstate=-1
@@ -232,6 +229,10 @@ class MyApp(wx.App):
                   if prevstate!=3: 
                     wx.PostEvent(self._notify_window, DTCEvent(0)) #clear list
                     DTCCodes=self.port.get_dtc()
+
+                    print DTCCodes
+                    print DTCCodes[0][0]
+                    print DTCCodes[0][1]
                     if len(DTCCodes)==0:
                       wx.PostEvent(self._notify_window, DTCEvent(["","","No DTC codes (codes cleared)"]))
                     for i in range (0,len(DTCCodes)):
@@ -275,6 +276,11 @@ class MyApp(wx.App):
         self.GetDTCButton.Enable(True)
         self.ClearDTCButton.Enable(True)
 
+        os.popen('dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:"Trying to connecting to ECU, wait some seconds..."')
+
+##
+##
+##
         def sensor_toggle(e):
             sel = e.m_itemIndex
             state = self.senprod.active[sel]
@@ -423,7 +429,6 @@ class MyApp(wx.App):
 
 #m
         self.status.Append(["BT dev",self.btname]);
-
         
         self.nb.AddPage(self.status, "Status")
         
@@ -450,15 +455,17 @@ class MyApp(wx.App):
         self.filemenu.Append(ID_EXIT,"E&xit"," Terminate the program")
 
         self.settingmenu = wx.Menu()
-        self.settingmenu.Append(ID_CONFIG,"Search BT... "," Configure pyOBD")
-        self.settingmenu.Append(ID_RESET,"Connect"," Reopen and connect to device")
+        self.settingmenu.Append(ID_CONFIG,"Search and connect paired BT dongle"," Configure pyOBD")
+        self.settingmenu.Append(ID_RESET,"Connect to ECU"," Reopen and connect to device")
         self.settingmenu.Append(ID_DISCONNECT,"Disconnect","Close connection to device")
 
+
         self.dtcmenu= wx.Menu()
         # tady toto nastavi automaticky tab DTC a provede akci
         self.dtcmenu.Append(ID_GETC  ,"Get DTCs",   " Get DTC Codes")
         self.dtcmenu.Append(ID_CLEAR ,"Clear DTC",  " Clear DTC Codes")
-        #self.dtcmenu.Append(ID_LOOK  ,"Code Lookup"," Lookup DTC Codes")
+
+#m        self.dtcmenu.Append(ID_LOOK  ,"Code Lookup"," Lookup DTC Codes")
 
         self.helpmenu = wx.Menu()
         
@@ -496,6 +503,8 @@ class MyApp(wx.App):
         frame.Show(True)
         frame.SetSize((520,400))
         self.sensor_control_off()
+        self.settingmenu.Enable(ID_RESET,False)
+        self.settingmenu.Enable(ID_DISCONNECT,False)
 
         return True
 
@@ -512,12 +521,16 @@ class MyApp(wx.App):
 
 
     def OnHelpAboutMaemo(self,event):
-        Text = """
-Adaptet to work with n900
-by emme750 at www.smartphonetab.net
+        Text = """Adaptet to work with n900 by m750
+Now work only with BT ELM OBD devices. 
 
-Now work only with bluetooth ELM OBD
-devices.
+Note: pyOBD does not recognize all the 
+error codes, especially those personalized 
+by the cars factories. If the ECU sends 
+one unrecognized error, the program stops. 
+Eventually you can edit the file: 
+  /home/opt/obd2_codes.py 
+and add that particular error code. 
 
 """
 
@@ -582,8 +595,20 @@ either version 2 of the License, or (at your option) any later version.
           self.dtc.Append(event.data)
     
     def OnDisconnect(self,event): #disconnect connection to ECU
+        global btaddr
+        self.btname = " "
         self.ThreadControl=666
         self.sensor_control_off()
+
+        bus = dbus.SystemBus()
+        manager = dbus.Interface(bus.get_object("org.bluez", "/"),"org.bluez.Manager")
+        adapter = dbus.Interface(bus.get_object("org.bluez", manager.DefaultAdapter()),"org.bluez.Adapter")
+        adapter.SetProperty('Powered',False)
+        time.sleep(0.1)
+        self.settingmenu.Enable(ID_RESET,False)
+
+
+
         
     def OpenPort(self,e):
         
@@ -614,6 +639,8 @@ either version 2 of the License, or (at your option) any later version.
         root = tree.AddRoot("Code Reference")
         proot = tree.AppendItem(root,"Powertrain (P) Codes")
         codes = obd_io.pcodes.keys()
+
+
         codes.sort()
         group = ""
         for c in codes:
@@ -665,24 +692,21 @@ either version 2 of the License, or (at your option) any later version.
     
     def scanSerial(self):
         
-
-
 #rfcomm bluetooth
-        global found, btname
+        global found, btname, btaddr
         target_address = None
         number_of_tries = 2
 
 # nome
+
         #target_name = "CB"
 
-
-
            # Loop a couple times in case the device/name isn't found the first time
         while target_address is None and number_of_tries > 0:
              number_of_tries = number_of_tries - 1
 
              # Discover bluetooth devices in the vicinity
-             print "Searching for OBD..."
+             print "Searching for BT dev..."
              nearby_devices = discover_devices()
 
              # Loop through each device and check its name for a prefix match
@@ -694,8 +718,8 @@ either version 2 of the License, or (at your option) any later version.
                if len(btname) > 2:
                  found=1
                  # Use the first device it finds that matches name
-                 print '    Found OBD'
-                 os.popen('dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:"Found a BT dev..."')
+                 print '    Found BT SPP dev'
+                 os.popen('dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:"Found a BT dev. Please wait"')
 
                  target_address = btaddr
 
@@ -707,6 +731,10 @@ either version 2 of the License, or (at your option) any later version.
                  service = "spp"
                  path = adapter.FindDevice(address)
                  seriale = dbus.Interface(bus.get_object("org.bluez", path),"org.bluez.Serial")
+                 try:
+                     node = seriale.Disconnect(service)
+                 except:
+                     pass
                  node = seriale.Connect(service)
                  #print "Connected %s to %s" % (node, address)
                  #print "Press CTRL-C to disconnect"
@@ -760,9 +788,6 @@ either version 2 of the License, or (at your option) any later version.
           except serial.SerialException:
             pass
 
-
-
-
             
         # ELM-USB shows up as /dev/tty.usbmodemXXXX, where XXXX is a changing hex string
         # on connection; so we have to search through all 64K options
@@ -781,8 +806,14 @@ either version 2 of the License, or (at your option) any later version.
     def Configure(self,e = None):
         global found, btname
         id = 0
+        self.btname = " "
+        bus = dbus.SystemBus()
+        manager = dbus.Interface(bus.get_object("org.bluez", "/"),"org.bluez.Manager")
+        adapter = dbus.Interface(bus.get_object("org.bluez", manager.DefaultAdapter()),"org.bluez.Adapter")
+        adapter.SetProperty('Powered',True)
+        time.sleep(0.6)
 
-        os.popen('dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:"Searching for BT dev..."')
+        os.popen('dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:"Searching for paired BT dev. Please wait..."')
 
         self.status.SetStringItem(3,1,""); 
         self.status.SetStringItem(4,1,""); 
@@ -790,18 +821,14 @@ either version 2 of the License, or (at your option) any later version.
         sizer = wx.BoxSizer(wx.VERTICAL)
         
         c1 = self.scanSerial()
-#        print c1
         c2=str(c1)
-#        print c2
         c3=c2[6:18]
-#        print c3
         ports=c3
         print ports
         self.portName = ports
         self.btname = btname
 
 
-
 #       rb = wx.RadioBox(diag, id, "Choose Serial Port", choices = ports, style = wx.RA_SPECIFY_COLS, majorDimension = 20)
 
                 
@@ -830,7 +857,7 @@ either version 2 of the License, or (at your option) any later version.
         
 #m        sizer.Add(self.OpenLinkButton)
         if found==1:
-           stringa="Found: "+btname+" - "+ports
+           stringa="Found: "+btname+" - "+ports + " - Try to connect?"
         else:
            stringa="BlueTooth OBD device NOT detected"
 
@@ -870,6 +897,9 @@ either version 2 of the License, or (at your option) any later version.
             #write configuration to cfg file
             self.config.write(open(self.configfilepath, 'wb'))
 
+            self.settingmenu.Enable(ID_RESET,True)
+            #self.settingmenu.Enable(ID_DISCONNECT,True)
+
         
     def OnExit(self,e = None):
         import sys
